@@ -1,12 +1,13 @@
 # -*- coding: utf-8 -*-
 
 from django.utils.translation import ugettext_lazy as _
+from django.forms.models import inlineformset_factory
 from django.test.client import RequestFactory
 from django import forms
 
 from models import (
     UserAuthNotification, UserAuthLogging, UserAuthToken, UserAuthAttempt,
-    UserAuthCode, UserAuthPhone, UserAuthQuestion)
+    UserAuthCode, UserAuthPhone, UserAuthQuestion, UserAuthIP, UserAuthIPRange)
 from defaults import CHECK_PASSWORD
 from utils.sign import Sign
 from utils import is_phone
@@ -15,7 +16,8 @@ from utils import is_phone
 class BasicForm(forms.Form):
     enabled = forms.BooleanField(label=_('Enabled'), required=False)
 
-    def decrypt(self, key, **kwargs):
+    @staticmethod
+    def decrypt(key, **kwargs):
         if 'initial' in kwargs:
             if kwargs['initial'] and key in kwargs['initial'].keys():
                 unsigned = Sign().unsign(kwargs['initial'][key])
@@ -32,6 +34,13 @@ class BasicForm(forms.Form):
             self.fields['current_password'] = forms.CharField(
                 label=_('Current password:'), widget=forms.PasswordInput)
 
+    def hide_field(self, model_class, field_name):
+        try:
+            model_class.objects.get(user=self.request.user)
+            self.fields.pop(field_name)
+        except model_class.DoesNotExist:
+            pass
+
     def clean_current_password(self):
         current_password = self.cleaned_data.get('current_password', '')
         if not self.request.user.check_password(current_password):
@@ -77,8 +86,8 @@ class PhoneBasicForm(BasicForm):
     phone = forms.CharField(label=_('Phone'), required=True, max_length=16)
 
     def __init__(self, *args, **kwargs):
-        self.decrypt('phone', **kwargs)
         super(PhoneBasicForm, self).__init__(*args, **kwargs)
+        self.hide_field(UserAuthPhone, 'phone')
 
     def clean_phone(self):
         phone = self.cleaned_data.get('phone')
@@ -102,17 +111,14 @@ class QuestionForm(BasicForm):
     code = forms.CharField(label=_('code'), required=True, max_length=16)
 
     def __init__(self, request, *args, **kwargs):
-        self.decrypt('code', **kwargs)
-        self.decrypt('question', **kwargs)
+        # self.decrypt('code', **kwargs)
+        # self.decrypt('question', **kwargs)
         super(QuestionForm, self).__init__(request, *args, **kwargs)
 
         self.fields['code'].label = _('Answer')
 
-        try:
-            UserAuthQuestion.objects.get(user=request.user)
-            self.fields.pop('code')
-        except UserAuthQuestion.DoesNotExist:
-            pass
+        self.hide_field(UserAuthQuestion, 'code')
+        self.hide_field(UserAuthQuestion, 'question')
 
     def save(self):
         model = super(QuestionForm, self).save()
@@ -150,6 +156,12 @@ class LoggingForm(BaseSettingsForm):
         exclude = ('user',)
 
 
+class IPSettingsForm(BaseSettingsForm):
+    class Meta:
+        model = UserAuthIP
+        exclude = ('user',)
+
+
 class ActivatePhoneForm(forms.Form):
     phone = forms.CharField(label=_('Phone'), required=True, max_length=16)
 
@@ -210,3 +222,6 @@ class IpBanForm(forms.Form):
         request = RequestFactory().get('/')
         request.META['REMOTE_ADDR'] = self.cleaned_data.get('ip')
         UserAuthAttempt.remove(request)
+
+
+IPRangeFormSet = inlineformset_factory(UserAuthIP, UserAuthIPRange)
